API Reference
=============

Complete API reference for all rapidgeo modules.

rapidgeo
--------

.. automodule:: rapidgeo
   :members:

rapidgeo.distance
-----------------

Core distance calculation module.

.. automodule:: rapidgeo.distance
   :members:
   :no-index:

rapidgeo.distance.geo
~~~~~~~~~~~~~~~~~~~~~

Geographic distance functions (Haversine, Vincenty).

.. automodule:: rapidgeo.distance.geo
   :members:

rapidgeo.distance.euclid  
~~~~~~~~~~~~~~~~~~~~~~~~

Planar/Euclidean distance functions.

.. automodule:: rapidgeo.distance.euclid
   :members:

rapidgeo.distance.batch
~~~~~~~~~~~~~~~~~~~~~~~

Batch distance operations.

.. automodule:: rapidgeo.distance.batch
   :members:

rapidgeo.formats
----------------

Coordinate format detection and conversion utilities.

.. automodule:: rapidgeo.formats
   :members:

rapidgeo.polyline
-----------------

Google Polyline Algorithm encoding and decoding.

.. automodule:: rapidgeo.polyline
   :members:

rapidgeo.simplify
-----------------

Line simplification using Douglas-Peucker algorithm.

.. automodule:: rapidgeo.simplify
   :members:

rapidgeo.simplify.batch
~~~~~~~~~~~~~~~~~~~~~~~

Batch simplification operations.

.. automodule:: rapidgeo.simplify.batch
   :members:

rapidgeo.similarity
-------------------

Curve similarity measures (Fréchet and Hausdorff distance).

.. automodule:: rapidgeo.similarity
   :members:

rapidgeo.similarity.frechet
~~~~~~~~~~~~~~~~~~~~~~~~~~~

Discrete Fréchet distance implementation.

.. automodule:: rapidgeo.similarity.frechet
   :members:

rapidgeo.similarity.hausdorff
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Hausdorff distance implementation.

.. automodule:: rapidgeo.similarity.hausdorff
   :members: